@@ -28,15 +28,14 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-commands.h,v 1.16 2006/05/31 15:40:12 paolo Exp $
+ * $Id: gedit-commands.h,v 1.20 2006/12/02 15:03:22 pborelli Exp $
  */
 
 #ifndef __GEDIT_COMMANDS_H__
 #define __GEDIT_COMMANDS_H__
 
 #include <gtk/gtkaction.h>
-#include "recent-files/egg-recent-item.h"
-#include "gedit-window.h"
+#include <gedit/gedit-window.h>
 
 G_BEGIN_DECLS
 
@@ -70,8 +69,6 @@ void		_gedit_cmd_file_new			(GtkAction   *action,
 							 GeditWindow *window);
 void		_gedit_cmd_file_open			(GtkAction   *action,
 							 GeditWindow *window);
-void		_gedit_cmd_file_open_recent		(EggRecentItem *item,
-							 GeditWindow *window);
 void		_gedit_cmd_file_save			(GtkAction   *action,
 							 GeditWindow *window);
 void		_gedit_cmd_file_save_as			(GtkAction   *action,
@@ -133,7 +130,9 @@ void		_gedit_cmd_search_clear_highlight	(GtkAction   *action,
 							 GeditWindow *window);
 void		_gedit_cmd_search_goto_line		(GtkAction   *action,
 							 GeditWindow *window);
-
+void		_gedit_cmd_search_incremental_search	(GtkAction   *action,
+							 GeditWindow *window);							 
+							 
 void		_gedit_cmd_documents_previous_document	(GtkAction   *action,
 							 GeditWindow *window);
 void		_gedit_cmd_documents_next_document	(GtkAction   *action,
