@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-ui.h,v 1.3 2005/12/14 17:25:12 pborelli Exp $
+ * $Id: gedit-ui.h,v 1.14 2006/12/02 15:03:22 pborelli Exp $
  */
 
 #ifndef __GEDIT_UI_H__
@@ -39,6 +39,11 @@
 
 #include "gedit-commands.h"
 
+/* FIXME: remove it when bumping dependency to GTK 2.10 */
+#ifndef GTK_STOCK_SELECT_ALL
+#	define GTK_STOCK_SELECT_ALL NULL
+#endif
+
 G_BEGIN_DECLS
 
 static const GtkActionEntry gedit_always_sensitive_menu_entries[] =
@@ -54,102 +59,114 @@ static const GtkActionEntry gedit_always_sensitive_menu_entries[] =
 
 	/* File menu */
 	{ "FileNew", GTK_STOCK_NEW, NULL, "<control>N",
-	  N_("Create a new document"), G_CALLBACK (gedit_cmd_file_new) },
+	  N_("Create a new document"), G_CALLBACK (_gedit_cmd_file_new) },
 	{ "FileOpen", GTK_STOCK_OPEN, N_("_Open..."), "<control>O",
-	  N_("Open a file"), G_CALLBACK (gedit_cmd_file_open) },
+	  N_("Open a file"), G_CALLBACK (_gedit_cmd_file_open) },
 	{ "FileOpenURI", NULL, N_("Open _Location..."), "<control>L",
-	  N_("Open a file from a specified location"), G_CALLBACK (gedit_cmd_file_open_uri) },
-	{ "FilePageSetup", NULL, N_("Page Set_up..."), NULL,
-	  N_("Setup the page settings"), G_CALLBACK (gedit_cmd_file_page_setup) },
+	  N_("Open a file from a specified location"), G_CALLBACK (_gedit_cmd_file_open_uri) },
 	
 	/* Edit menu */
 	{ "EditPreferences", GTK_STOCK_PREFERENCES, N_("Pr_eferences"), NULL,
-	  N_("Configure the application"), G_CALLBACK (gedit_cmd_edit_preferences) },
+	  N_("Configure the application"), G_CALLBACK (_gedit_cmd_edit_preferences) },
 
 	/* Help menu */
 	{"HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
-	 N_("Open the gedit manual"), G_CALLBACK (gedit_cmd_help_contents) },
+	 N_("Open the gedit manual"), G_CALLBACK (_gedit_cmd_help_contents) },
 	{ "HelpAbout", GTK_STOCK_ABOUT, NULL, NULL,
-	 N_("About this application"), G_CALLBACK (gedit_cmd_help_about) }
+	 N_("About this application"), G_CALLBACK (_gedit_cmd_help_about) }
 };
 
 static const GtkActionEntry gedit_menu_entries[] =
 {
 	/* File menu */
 	{ "FileSave", GTK_STOCK_SAVE, NULL, "<control>S",
-	  N_("Save the current file"), G_CALLBACK (gedit_cmd_file_save) },
+	  N_("Save the current file"), G_CALLBACK (_gedit_cmd_file_save) },
 	{ "FileSaveAs", GTK_STOCK_SAVE_AS, N_("Save _As..."), "<shift><control>S",
-	  N_("Save the current file with a different name"), G_CALLBACK (gedit_cmd_file_save_as) },
+	  N_("Save the current file with a different name"), G_CALLBACK (_gedit_cmd_file_save_as) },
 	{ "FileRevert", GTK_STOCK_REVERT_TO_SAVED, NULL, NULL,
-	  N_("Revert to a saved version of the file"), G_CALLBACK (gedit_cmd_file_revert) },
+	  N_("Revert to a saved version of the file"), G_CALLBACK (_gedit_cmd_file_revert) },
+	{ "FilePageSetup", NULL, N_("Page Set_up..."), NULL,
+	  N_("Setup the page settings"), G_CALLBACK (_gedit_cmd_file_page_setup) },
 	{ "FilePrintPreview", GTK_STOCK_PRINT_PREVIEW, N_("Print Previe_w"),"<control><shift>P",
-	  N_("Print preview"), G_CALLBACK (gedit_cmd_file_print_preview) },
+	  N_("Print preview"), G_CALLBACK (_gedit_cmd_file_print_preview) },
 	 { "FilePrint", GTK_STOCK_PRINT, N_("_Print..."), "<control>P",
-	  N_("Print the current page"), G_CALLBACK (gedit_cmd_file_print) },
+	  N_("Print the current page"), G_CALLBACK (_gedit_cmd_file_print) },
 	{ "FileClose", GTK_STOCK_CLOSE, NULL, "<control>W",
-	  N_("Close the current file"), G_CALLBACK (gedit_cmd_file_close) },
+	  N_("Close the current file"), G_CALLBACK (_gedit_cmd_file_close) },
 
 	/* Edit menu */
 	{ "EditUndo", GTK_STOCK_UNDO, NULL, "<control>Z",
-	  N_("Undo the last action"), G_CALLBACK (gedit_cmd_edit_undo) },
+	  N_("Undo the last action"), G_CALLBACK (_gedit_cmd_edit_undo) },
 	{ "EditRedo", GTK_STOCK_REDO, NULL, "<shift><control>Z",
-	  N_("Redo the last undone action"), G_CALLBACK (gedit_cmd_edit_redo) },
+	  N_("Redo the last undone action"), G_CALLBACK (_gedit_cmd_edit_redo) },
 	{ "EditCut", GTK_STOCK_CUT, NULL, "<control>X",
-	  N_("Cut the selection"), G_CALLBACK (gedit_cmd_edit_cut) },
+	  N_("Cut the selection"), G_CALLBACK (_gedit_cmd_edit_cut) },
 	{ "EditCopy", GTK_STOCK_COPY, NULL, "<control>C",
-	  N_("Copy the selection"), G_CALLBACK (gedit_cmd_edit_copy) },
+	  N_("Copy the selection"), G_CALLBACK (_gedit_cmd_edit_copy) },
 	{ "EditPaste", GTK_STOCK_PASTE, NULL, "<control>V",
-	  N_("Paste the clipboard"), G_CALLBACK (gedit_cmd_edit_paste) },
+	  N_("Paste the clipboard"), G_CALLBACK (_gedit_cmd_edit_paste) },
 	{ "EditDelete", GTK_STOCK_DELETE, NULL, NULL,
-	  N_("Delete the selected text"), G_CALLBACK (gedit_cmd_edit_delete) },
-	{ "EditSelectAll", NULL, N_("Select _All"), "<control>A",
-	  N_("Select the entire document"), G_CALLBACK (gedit_cmd_edit_select_all) },
+	  N_("Delete the selected text"), G_CALLBACK (_gedit_cmd_edit_delete) },
+	{ "EditSelectAll", GTK_STOCK_SELECT_ALL, N_("Select _All"), "<control>A",
+	  N_("Select the entire document"), G_CALLBACK (_gedit_cmd_edit_select_all) },
 
 	/* View menu */
 	{ "ViewHighlightMode", NULL, N_("_Highlight Mode") },
 
 	/* Search menu */
 	{ "SearchFind", GTK_STOCK_FIND, N_("_Find..."), "<control>F",
-	  N_("Search for text"), G_CALLBACK (gedit_cmd_search_find) },
+	  N_("Search for text"), G_CALLBACK (_gedit_cmd_search_find) },
 	{ "SearchFindNext", NULL, N_("Find Ne_xt"), "<control>G",
-	  N_("Search forwards for the same text"), G_CALLBACK (gedit_cmd_search_find_next) },
+	  N_("Search forwards for the same text"), G_CALLBACK (_gedit_cmd_search_find_next) },
 	{ "SearchFindPrevious", NULL, N_("Find Pre_vious"), "<shift><control>G",
-	  N_("Search backwards for the same text"), G_CALLBACK (gedit_cmd_search_find_prev) },
-	{ "SearchReplace", GTK_STOCK_FIND_AND_REPLACE, N_("_Replace..."), "<control>R",
-	  N_("Search for and replace text"), G_CALLBACK (gedit_cmd_search_replace) },
+	  N_("Search backwards for the same text"), G_CALLBACK (_gedit_cmd_search_find_prev) },
+	{ "SearchReplace", GTK_STOCK_FIND_AND_REPLACE, N_("_Replace..."), "<control>H",
+	  N_("Search for and replace text"), G_CALLBACK (_gedit_cmd_search_replace) },
+	{ "SearchClearHighlight", NULL, N_("_Clear Highlight"), "<shift><control>K",
+	  N_("Clear highlighting of search matches"), G_CALLBACK (_gedit_cmd_search_clear_highlight) },
 	{ "SearchGoToLine", GTK_STOCK_JUMP_TO, N_("Go to _Line..."), "<control>I",
-	  N_("Go to a specific line"), G_CALLBACK (gedit_cmd_search_goto_line) },
+	  N_("Go to a specific line"), G_CALLBACK (_gedit_cmd_search_goto_line) },
+	{ "SearchIncrementalSearch", GTK_STOCK_FIND, N_("Incremental search..."), "<control>K",
+	  N_("Incrementally search for text"), G_CALLBACK (_gedit_cmd_search_incremental_search) },
 
 	/* Documents menu */
 	{ "FileSaveAll", GTK_STOCK_SAVE, N_("_Save All"), "<shift><control>L",
-	  N_("Save all open files"), G_CALLBACK (gedit_cmd_file_save_all) },
+	  N_("Save all open files"), G_CALLBACK (_gedit_cmd_file_save_all) },
 	{ "FileCloseAll", GTK_STOCK_CLOSE, N_("_Close All"), "<shift><control>W",
-	  N_("Close all open files"), G_CALLBACK (gedit_cmd_file_close_all) },
+	  N_("Close all open files"), G_CALLBACK (_gedit_cmd_file_close_all) },
+	{ "DocumentsPreviousDocument", NULL, N_("_Previous Document"), "<alt><control>Page_Up",
+	  N_("Activate previous document"), G_CALLBACK (_gedit_cmd_documents_previous_document) },
+	{ "DocumentsNextDocument", NULL, N_("_Next Document"), "<alt><control>Page_Down",
+	  N_("Activate next document"), G_CALLBACK (_gedit_cmd_documents_next_document) },
 	{ "DocumentsMoveToNewWindow", NULL, N_("_Move to New Window"), NULL,
-	  N_("Move the current document to a new window"), G_CALLBACK (gedit_cmd_documents_move_to_new_window) }
+	  N_("Move the current document to a new window"), G_CALLBACK (_gedit_cmd_documents_move_to_new_window) }
 };
 
 /* separate group, should be sensitive even when there are no tabs */
 static const GtkActionEntry gedit_quit_menu_entries[] =
 {
 	{ "FileQuit", GTK_STOCK_QUIT, NULL, "<control>Q",
-	  N_("Quit the program"), G_CALLBACK (gedit_cmd_file_quit) }
+	  N_("Quit the program"), G_CALLBACK (_gedit_cmd_file_quit) }
 };
 
 static const GtkToggleActionEntry gedit_always_sensitive_toggle_menu_entries[] =
 {
 	{ "ViewToolbar", NULL, N_("_Toolbar"), NULL,
 	  N_("Show or hide the toolbar in the current window"),
-	  G_CALLBACK (gedit_cmd_view_show_toolbar), TRUE },
+	  G_CALLBACK (_gedit_cmd_view_show_toolbar), TRUE },
 	{ "ViewStatusbar", NULL, N_("_Statusbar"), NULL,
 	  N_("Show or hide the statusbar in the current window"),
-	  G_CALLBACK (gedit_cmd_view_show_statusbar), TRUE },
+	  G_CALLBACK (_gedit_cmd_view_show_statusbar), TRUE },
 	{ "ViewSidePane", NULL, N_("Side _Pane"), "F9",
 	  N_("Show or hide the side pane in the current window"),
-	  G_CALLBACK (gedit_cmd_view_show_side_pane), FALSE },
-	{ "ViewBottomPanel", NULL, N_("_Bottom Panel"), "<control>F9",
-	  N_("Show or hide the bottom panel in the current window"),
-	  G_CALLBACK (gedit_cmd_view_show_bottom_panel), FALSE }	  
+	  G_CALLBACK (_gedit_cmd_view_show_side_pane), FALSE }
+};
+
+static const GtkToggleActionEntry gedit_toggle_menu_entries[] =
+{
+	{ "ViewBottomPane", NULL, N_("_Bottom Pane"), "<control>F9",
+	  N_("Show or hide the bottom pane in the current window"),
+	  G_CALLBACK (_gedit_cmd_view_show_bottom_pane), FALSE }
 };
 
 G_END_DECLS
