@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit.c,v 1.140 2006/05/29 10:14:28 paolo Exp $
+ * $Id: gedit.c,v 1.145 2006/12/17 15:41:19 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -44,13 +44,11 @@
 
 #include "gedit-app.h"
 #include "gedit-commands.h"
-#include "gedit-convert.h"
 #include "gedit-debug.h"
 #include "gedit-encodings.h"
 #include "gedit-metadata-manager.h"
 #include "gedit-plugins-engine.h"
 #include "gedit-prefs-manager-app.h"
-#include "gedit-recent.h"
 #include "gedit-session.h"
 #include "gedit-utils.h"
 #include "gedit-window.h"
@@ -216,14 +214,20 @@ on_message_received (const char *message,
 
 	/* header */
 	params = g_strsplit (commands[0], "\t", 4);
-	startup_timestamp = atoi (params[0]); /* CHECK if this is safe */
-	display_name = g_strdup (params[1]);
+	startup_timestamp = atoi (params[0]);
+	display_name = params[1];
 	screen_number = atoi (params[2]);
 	workspace = atoi (params[3]);
 
 	display = display_open_if_needed (display_name);
+	if (display == NULL)
+	{
+		g_warning ("Could not open display %s\n", display_name);
+		g_strfreev (params);
+		goto out;
+	}
+
 	screen = gdk_display_get_screen (display, screen_number);
-	g_free (display_name);
 
 	g_strfreev (params);
 
@@ -268,8 +272,6 @@ on_message_received (const char *message,
 		g_strfreev (params);
 	}
 
-	g_strfreev (commands);
-
 	/* execute the commands */
 
 	app = gedit_app_get_default ();
@@ -329,6 +331,9 @@ on_message_received (const char *message,
 	g_slist_free (file_list);
 	file_list = NULL;
 
+ out:
+	g_strfreev (commands);
+
 	new_window_option = FALSE;
 	new_document_option = FALSE;
 	encoding = NULL;
@@ -502,21 +507,20 @@ main (int argc, char *argv[])
 					   GEDIT_ICONDIR);
 
 	/* Set default icon */
-	gtk_window_set_default_icon_name ("text-editor");
+	gtk_window_set_default_icon_name ("accessories-text-editor");
 
 	/* Load user preferences */
 	gedit_debug_message (DEBUG_APP, "Init prefs manager");
 	gedit_prefs_manager_app_init ();
 
-	gedit_debug_message (DEBUG_APP, "Init recent files");
-	gedit_recent_init ();
-
+	/* Initialize authentication manager */
+	gedit_debug_message (DEBUG_APP, "Init authentication manager");	
+	gnome_authentication_manager_init ();
+	
 	/* Init plugins engine */
 	gedit_debug_message (DEBUG_APP, "Init plugins");	
 	gedit_plugins_engine_init ();
 
-	gedit_debug_message (DEBUG_APP, "Init authentication manager");	
-	gnome_authentication_manager_init ();
 	gtk_about_dialog_set_url_hook (gedit_utils_activate_url, NULL, NULL);
 	
 	/* Initialize session management */
