@@ -121,7 +121,6 @@ struct _GeditFileBrowserWidgetPrivate
 	GdkCursor *cursor;
 
 	GtkWidget *filter_expander;
-	GtkWidget *filter_vbox;
 	GtkWidget *filter_entry;
 
 	GtkUIManager *manager;
@@ -215,23 +214,24 @@ static void
 free_name_icon (gpointer data)
 {
 	NameIcon * item;
-	
+
 	if (data == NULL)
 		return;
 
 	item = (NameIcon *)(data);
 
 	g_free (item->name);
-	
+
 	if (item->icon)
 		g_object_unref (item->icon);
-	
+
 	g_free (item);
 }
 
 static FilterFunc *
 filter_func_new (GeditFileBrowserWidget * obj,
-		 GeditFileBrowserWidgetFilterFunc func, gpointer user_data)
+		 GeditFileBrowserWidgetFilterFunc func,
+		 gpointer user_data)
 {
 	FilterFunc *result;
 
@@ -295,7 +295,6 @@ static void
 gedit_file_browser_widget_finalize (GObject * object)
 {
 	GeditFileBrowserWidget *obj = GEDIT_FILE_BROWSER_WIDGET (object);
-	GSList *item;
 	GList *loc;
 
 	remove_path_items (obj);
@@ -310,9 +309,7 @@ gedit_file_browser_widget_finalize (GObject * object)
 	g_object_unref (obj->priv->bookmarks_store);
 	g_object_unref (obj->priv->combo_model);
 
-	for (item = obj->priv->filter_funcs; item; item = item->next)
-		g_free (item->data);
-
+	g_slist_foreach (obj->priv->filter_funcs, (GFunc) g_free, NULL);
 	g_slist_free (obj->priv->filter_funcs);
 
 	for (loc = obj->priv->locations; loc; loc = loc->next)
@@ -325,8 +322,7 @@ gedit_file_browser_widget_finalize (GObject * object)
 
 	g_hash_table_destroy (obj->priv->bookmarks_hash);
 
-	G_OBJECT_CLASS (gedit_file_browser_widget_parent_class)->
-	    finalize (object);
+	G_OBJECT_CLASS (gedit_file_browser_widget_parent_class)->finalize (object);
 }
 
 static void
@@ -631,7 +627,7 @@ static void
 insert_location_path (GeditFileBrowserWidget * obj)
 {
 	Location *loc;
-	GnomeVFSURI *virtual;
+	GnomeVFSURI *virtual_root;
 	GnomeVFSURI *root;
 	GnomeVFSURI *current = NULL;
 	GnomeVFSURI * tmp;
@@ -646,18 +642,18 @@ insert_location_path (GeditFileBrowserWidget * obj)
 
 	loc = (Location *) (obj->priv->current_location->data);
 
-	virtual = gnome_vfs_uri_new (loc->virtual_root);
+	virtual_root = gnome_vfs_uri_new (loc->virtual_root);
 	root = gnome_vfs_uri_new (loc->root);
-	current = virtual;
+	current = virtual_root;
 
 	combo_find_by_id (obj, SEPARATOR_ID, &separator);
 	
-	indent = uri_num_parents (virtual, root);
+	indent = uri_num_parents (virtual_root, root);
 
 	while (current != NULL) {
 		insert_path_item (obj, current, &separator, &iter, indent--);
 
-		if (current == virtual) {
+		if (current == virtual_root) {
 			g_signal_handlers_block_by_func (obj->priv->combo,
 							 on_combo_changed,
 							 obj);
@@ -671,20 +667,20 @@ insert_location_path (GeditFileBrowserWidget * obj)
 		}
 
 		if (gnome_vfs_uri_equal (current, root) || !gnome_vfs_uri_has_parent (current)) {
-			if (current != virtual)
+			if (current != virtual_root)
 				gnome_vfs_uri_unref (current);
 			break;
 		}
 
 		tmp = gnome_vfs_uri_get_parent (current);
 		
-		if (current != virtual)
+		if (current != virtual_root)
 			gnome_vfs_uri_unref (current);
 
 		current = tmp;
 	}
 
-	gnome_vfs_uri_unref (virtual);
+	gnome_vfs_uri_unref (virtual_root);
 	gnome_vfs_uri_unref (root);
 }
 
@@ -706,7 +702,6 @@ check_current_item (GeditFileBrowserWidget * obj, gboolean show_path)
 		gtk_tree_store_remove (obj->priv->combo_model, &separator);
 }
 
-
 static void
 fill_combo_model (GeditFileBrowserWidget * obj)
 {
@@ -715,16 +710,16 @@ fill_combo_model (GeditFileBrowserWidget * obj)
 
 	gtk_tree_store_append (store, &iter, NULL);
 	gtk_tree_store_set (store, &iter,
-			    COLUMN_ICON, gedit_file_browser_utils_pixbuf_from_theme(GTK_STOCK_HOME, GTK_ICON_SIZE_MENU),
+			    COLUMN_ICON, gedit_file_browser_utils_pixbuf_from_theme (GTK_STOCK_HOME, GTK_ICON_SIZE_MENU),
 			    COLUMN_NAME, _("Bookmarks"),
 			    COLUMN_ID, BOOKMARKS_ID, -1);
-
-	/*gtk_tree_store_append(store, &iter, NULL);
-	   gtk_tree_store_set(store, &iter,
-	   COLUMN_ICON, GTK_STOCK_OPEN,
-	   COLUMN_NAME, "Recent",
-	   COLUMN_ID, RECENT_ID, -1); */
-
+#if 0
+	gtk_tree_store_append (store, &iter, NULL);
+	gtk_tree_store_set (store, &iter,
+			    COLUMN_ICON, gedit_file_browser_utils_pixbuf_from_theme (GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU),
+			    COLUMN_NAME, _("Recent Files"),
+			    COLUMN_ID, RECENTS_ID, -1);
+#endif
 	gtk_combo_box_set_row_separator_func (GTK_COMBO_BOX
 					      (obj->priv->combo),
 					      separator_func, obj, NULL);
@@ -803,10 +798,10 @@ static GtkActionEntry toplevel_actions[] =
 	{"FilterMenuAction", NULL, "_Filter"}
 };
 
-static GtkActionEntry tree_actions[] = 
+static const GtkActionEntry tree_actions[] = 
 {
-	{"DirectoryNew", GTK_STOCK_ADD, N_("_New Directory"), NULL,
-	 N_("Add new empty directory"),
+	{"DirectoryNew", GTK_STOCK_ADD, N_("_New Folder"), NULL,
+	 N_("Add new empty folder"),
 	 G_CALLBACK (on_action_directory_new)},
 	{"FileNew", GTK_STOCK_NEW, N_("New F_ile"), NULL,
 	 N_("Add new empty file"), G_CALLBACK (on_action_file_new)},
@@ -814,20 +809,20 @@ static GtkActionEntry tree_actions[] =
 	 N_("Open the parent folder"), G_CALLBACK (on_action_directory_up)}
 };
 
-static GtkActionEntry tree_actions_selection[] = 
+static const GtkActionEntry tree_actions_selection[] = 
 {
 	{"FileRename", NULL, N_("_Rename"), NULL,
-	 N_("Rename selected file or directory"),
+	 N_("Rename selected file or folder"),
 	 G_CALLBACK (on_action_file_rename)},
 	{"FileMoveToTrash", "gnome-stock-trash", N_("_Move To Trash"), NULL,
-	 N_("Move selected file or directory to trash"),
+	 N_("Move selected file or folder to trash"),
 	 G_CALLBACK (on_action_file_move_to_trash)},
 	{"FileDelete", GTK_STOCK_DELETE, N_("_Delete"), NULL,
-	 N_("Delete selected file or directory"),
+	 N_("Delete selected file or folder"),
 	 G_CALLBACK (on_action_file_delete)}
 };
 
-static GtkActionEntry tree_actions_sensitive[] = 
+static const GtkActionEntry tree_actions_sensitive[] = 
 {
 	{"DirectoryPrevious", GTK_STOCK_GO_BACK, N_("_Previous Location"),
 	 NULL,
@@ -837,16 +832,16 @@ static GtkActionEntry tree_actions_sensitive[] =
 	 N_("Go to the next visited location"), G_CALLBACK (on_action_directory_next)},
 	{"DirectoryRefresh", GTK_STOCK_REFRESH, N_("Re_fresh View"), NULL,
 	 N_("Refresh the view"), G_CALLBACK (on_action_directory_refresh)},
-	{"DirectoryOpen", GTK_STOCK_OPEN, N_("_View Directory"), NULL,
-	 N_("View directory in file manager"),
+	{"DirectoryOpen", GTK_STOCK_OPEN, N_("_View Folder"), NULL,
+	 N_("View folder in file manager"),
 	 G_CALLBACK (on_action_directory_open)}
 };
 
-static GtkToggleActionEntry tree_actions_toggle[] = 
+static const GtkToggleActionEntry tree_actions_toggle[] = 
 {
 	{"FilterHidden", GTK_STOCK_DIALOG_AUTHENTICATION,
 	 N_("Show _Hidden"), NULL,
-	 N_("Show hidden files and directories"),
+	 N_("Show hidden files and folders"),
 	 G_CALLBACK (on_action_filter_hidden), FALSE},
 	{"FilterBinary", NULL, N_("Show _Binary"), NULL,
 	 N_("Show binary files"), G_CALLBACK (on_action_filter_binary),
@@ -918,6 +913,7 @@ create_toolbar (GeditFileBrowserWidget * obj)
 
 	toolbar = gtk_ui_manager_get_widget (manager, "/ToolBar");
 	gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
+	gtk_toolbar_set_icon_size (GTK_TOOLBAR (toolbar), GTK_ICON_SIZE_MENU);
 
 	/* Previous directory menu tool item */
 	obj->priv->location_previous_menu = gtk_menu_new ();
@@ -938,8 +934,7 @@ create_toolbar (GeditFileBrowserWidget * obj)
 						(widget),
 						GTK_TOOLBAR (toolbar)->
 						tooltips,
-						_
-						("Go to a previously opened location"),
+						_("Go to a previously opened location"),
 						NULL);
 
 	action =
@@ -1126,7 +1121,7 @@ create_filter (GeditFileBrowserWidget * obj)
 	GtkWidget *vbox;
 	GtkWidget *entry;
 
-	expander = gtk_expander_new (_("Advanced filtering"));
+	expander = gtk_expander_new_with_mnemonic (_("_Advanced filtering"));
 	gtk_widget_show (expander);
 	gtk_box_pack_start (GTK_BOX (obj), expander, FALSE, FALSE, 0);
 
@@ -1134,7 +1129,6 @@ create_filter (GeditFileBrowserWidget * obj)
 	gtk_widget_show (vbox);
 
 	obj->priv->filter_expander = expander;
-	obj->priv->filter_vbox = vbox;
 
 	entry = gtk_entry_new ();
 	gtk_widget_show (entry);
@@ -1680,7 +1674,7 @@ void
 gedit_file_browser_widget_set_root_and_virtual_root (GeditFileBrowserWidget
 						     * obj,
 						     gchar const *root,
-						     gchar const *virtual)
+						     gchar const *virtual_root)
 {
 	GeditFileBrowserStoreResult result;
 
@@ -1688,14 +1682,14 @@ gedit_file_browser_widget_set_root_and_virtual_root (GeditFileBrowserWidget
 					   GTK_TREE_MODEL (obj->priv->
 							   file_store));
 
-	if (!virtual)
+	if (!virtual_root)
 		result =
 		    gedit_file_browser_store_set_root_and_virtual_root 
 		    (obj->priv->file_store, root, root);
 	else
 		result =
 		    gedit_file_browser_store_set_root_and_virtual_root
-		    (obj->priv->file_store, root, virtual);
+		    (obj->priv->file_store, root, virtual_root);
 
 	if (result == GEDIT_FILE_BROWSER_STORE_RESULT_NO_CHANGE)
 		on_virtual_root_changed (obj->priv->file_store, NULL, obj);
@@ -1704,13 +1698,13 @@ gedit_file_browser_widget_set_root_and_virtual_root (GeditFileBrowserWidget
 void
 gedit_file_browser_widget_set_root (GeditFileBrowserWidget * obj,
 				    gchar const *root, 
-				    gboolean virtual)
+				    gboolean virtual_root)
 {
 	GnomeVFSURI *uri;
 	GnomeVFSURI *parent;
 	gchar *str;
 
-	if (!virtual) {
+	if (!virtual_root) {
 		gedit_file_browser_widget_set_root_and_virtual_root (obj,
 								     root,
 								     NULL);
@@ -1771,7 +1765,6 @@ gedit_file_browser_widget_get_filter_entry (GeditFileBrowserWidget * obj)
 	return obj->priv->filter_entry;
 }
 
-
 gulong
 gedit_file_browser_widget_add_filter (GeditFileBrowserWidget * obj,
 				      GeditFileBrowserWidgetFilterFunc
@@ -1812,12 +1805,6 @@ gedit_file_browser_widget_remove_filter (GeditFileBrowserWidget * obj,
 	}
 }
 
-GtkVBox *
-gedit_file_browser_widget_get_filter_vbox (GeditFileBrowserWidget * obj)
-{
-	return GTK_VBOX (obj->priv->filter_vbox);
-}
-
 void 
 gedit_file_browser_widget_set_filter_pattern (GeditFileBrowserWidget * obj,
                                               gchar const *pattern)
@@ -1900,15 +1887,15 @@ virtual_root_is_root (GeditFileBrowserWidget * obj,
                       GeditFileBrowserStore  * model)
 {
 	GtkTreeIter root;
-	GtkTreeIter virtual;
+	GtkTreeIter virtual_root;
 	
 	if (!gedit_file_browser_store_get_iter_root (model, &root))
 		return TRUE;
 	
-	if (!gedit_file_browser_store_get_iter_virtual_root (model, &virtual))
+	if (!gedit_file_browser_store_get_iter_virtual_root (model, &virtual_root))
 		return TRUE;
 	
-	return gedit_file_browser_store_iter_equal (model, &root, &virtual);
+	return gedit_file_browser_store_iter_equal (model, &root, &virtual_root);
 }
 
 static void
@@ -2054,7 +2041,7 @@ on_model_set (GObject * gobject, GParamSpec * arg1,
 			      "DirectoryPrevious"), TRUE);
 		}
 
-		gtk_widget_set_sensitive (obj->priv->filter_vbox, FALSE);
+		gtk_widget_set_sensitive (obj->priv->filter_expander, FALSE);
 	} else if (GEDIT_IS_FILE_BROWSER_STORE (model)) {
 		add_signal (obj, model,
 			    g_signal_connect (model, "begin-loading",
@@ -2074,7 +2061,7 @@ on_model_set (GObject * gobject, GParamSpec * arg1,
 			    g_signal_connect (model, "error",
 					      G_CALLBACK
 					      (on_file_store_error), obj));
-		gtk_widget_set_sensitive (obj->priv->filter_vbox, TRUE);
+		gtk_widget_set_sensitive (obj->priv->filter_expander, TRUE);
 	}
 
 	update_sensitivity (obj);
@@ -2113,6 +2100,7 @@ on_combo_changed (GtkComboBox * combo, GeditFileBrowserWidget * obj)
 	case BOOKMARKS_ID:
 		gedit_file_browser_widget_show_bookmarks (obj);
 		break;
+
 	case PATH_ID:
 		gtk_tree_model_get (GTK_TREE_MODEL
 				    (obj->priv->combo_model), &iter,
